"""
Main interface for forecastquery service client

Usage::

    import boto3
    from mypy_boto3.forecastquery import ForecastQueryServiceClient

    session = boto3.Session()

    client: ForecastQueryServiceClient = boto3.client("forecastquery")
    session_client: ForecastQueryServiceClient = session.client("forecastquery")
"""
# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
from typing import Any, Dict, TYPE_CHECKING
from botocore.exceptions import ClientError as Boto3ClientError
from mypy_boto3_forecastquery.type_defs import QueryForecastResponseTypeDef


__all__ = ("ForecastQueryServiceClient",)


class Exceptions:
    ClientError: Boto3ClientError
    InvalidInputException: Boto3ClientError
    InvalidNextTokenException: Boto3ClientError
    LimitExceededException: Boto3ClientError
    ResourceInUseException: Boto3ClientError
    ResourceNotFoundException: Boto3ClientError


class ForecastQueryServiceClient:
    """
    [ForecastQueryService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/forecastquery.html#ForecastQueryService.Client)
    """

    exceptions: Exceptions

    def can_paginate(self, operation_name: str) -> bool:
        """
        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/forecastquery.html#ForecastQueryService.Client.can_paginate)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Dict[str, Any] = None,
        ExpiresIn: int = 3600,
        HttpMethod: str = None,
    ) -> str:
        """
        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/forecastquery.html#ForecastQueryService.Client.generate_presigned_url)
        """

    def query_forecast(
        self,
        ForecastArn: str,
        Filters: Dict[str, str],
        StartDate: str = None,
        EndDate: str = None,
        NextToken: str = None,
    ) -> QueryForecastResponseTypeDef:
        """
        [Client.query_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/forecastquery.html#ForecastQueryService.Client.query_forecast)
        """



"""
Main interface for forecastquery service.

Usage::

    import boto3
    from mypy_boto3.forecastquery import (
        Client,
        ForecastQueryServiceClient,
        )

    session = boto3.Session()

    client: ForecastQueryServiceClient = boto3.client("forecastquery")
    session_client: ForecastQueryServiceClient = session.client("forecastquery")
"""
from mypy_boto3_forecastquery.client import (
    ForecastQueryServiceClient,
    ForecastQueryServiceClient as Client,
)


__all__ = ("Client", "ForecastQueryServiceClient")



"""
Main interface for forecastquery service type definitions.

Usage::

    from mypy_boto3.forecastquery.type_defs import DataPointTypeDef

    data: DataPointTypeDef = {...}
"""
import sys
from typing import Dict, List

if sys.version_info >= (3, 8):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict


__all__ = ("DataPointTypeDef", "ForecastTypeDef", "QueryForecastResponseTypeDef")

DataPointTypeDef = TypedDict("DataPointTypeDef", {"Timestamp": str, "Value": float}, total=False)

ForecastTypeDef = TypedDict(
    "ForecastTypeDef", {"Predictions": Dict[str, List[DataPointTypeDef]]}, total=False
)

QueryForecastResponseTypeDef = TypedDict(
    "QueryForecastResponseTypeDef", {"Forecast": ForecastTypeDef}, total=False
)
